from setuptools import setup

setup(name='pr_distr_set',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['pr_distr_set'],
      author = 'Sushant',
      zip_safe=False)
